ESetStandbyImage class
ESC 设置待机图片
协议分三步:
- 发送开始包(帧头 10 FF 36 00 A5),携带图片总长度
- 分包发送图片数据(帧头 10 FF 36 01 A5)
- 发送结束包(帧头 10 FF 36 02 A5)
每包均包含校验和(累加和 % 255)及结束符 0x5A,并等待设备回复确认。
Constructors
- ESetStandbyImage({required ConnectedDevice device, required Uint8List imageData, int fragmentSize = _defaultFragmentSize, int timeoutMs = _defaultTimeoutMs})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
) → Future< void> - 执行完整的待机图片发送流程。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited